import { getInfo, login, logout } from "@/api/login";
import { getToken, removeToken, setToken } from "@/utils/auth";
import defAva from "@/assets/images/profile.jpg";
import { cloneDeep } from "lodash-es";

const useUserStore = defineStore("user", {
  state: () => ({
    token: getToken(),
    name: "",
    avatar: "",
    roles: [],
    tenant: "" /*登录后*/,
    tempTenant: null /*临时的tenant*/,
    tempTenantName: null,
    permissions: [],
    userInfoRes: null,
  }),
  actions: {
    setUserInfoRes(res) {
      this.userInfoRes = cloneDeep(res);
    },
    // 登录
    login(userInfo) {
      const username = userInfo.username.trim();
      const password = userInfo.password;
      const tenant = userInfo.tenant;
      const code = userInfo.code;
      const uuid = userInfo.uuid;
      return new Promise((resolve, reject) => {
        this.tenant = tenant;
        login(username, password, code, uuid)
          .then((res) => {
            setToken(res.token);
            this.token = res.token;
            resolve();
          })
          .catch((error) => {
            reject(error);
          });
      });
    },
    // 获取用户信息
    getInfo() {
      return new Promise((resolve, reject) => {
        getInfo()
          .then((res) => {
            if (!this.userInfoRes) {
              this.setUserInfoRes(res);
            }
            const user = res.user;
            const avatar =
              user.avatar == "" || user.avatar == null
                ? defAva
                : import.meta.env.VITE_APP_BASE_API + user.avatar;

            if (res.roles && res.roles.length > 0) {
              // 验证返回的roles是否是一个非空数组
              this.roles = res.roles;
              this.permissions = res.permissions;
            } else {
              this.roles = ["ROLE_DEFAULT"];
            }
            this.name = user.userName;
            this.avatar = avatar;
            resolve(res);
          })
          .catch((error) => {
            reject(error);
          });
      });
    },
    // 退出系统
    logOut() {
      return new Promise((resolve, reject) => {
        logout(this.token)
          .then(() => {
            this.token = "";
            this.roles = [];
            this.permissions = [];
            this.userInfoRes = null;
            this.tenant = null;
            removeToken();
            resolve();
          })
          .catch((error) => {
            reject(error);
          });
      });
    },
    // 非正常退出系统
    abnormalLogOut() {
      return new Promise((resolve, reject) => {
        this.token = "";
        this.roles = [];
        this.permissions = [];
        this.userInfoRes = null;
        removeToken();
        resolve();
      });
    },
    setTempTenant(tenant) {
      this.tempTenant = tenant.tenantId;
      this.tempTenantName = tenant.companyName;
    },
  },
  persist: [
    {
      paths: ["tenant" /*"userInfoRes"*/, "tempTenant", "tempTenantName"],
      storage: localStorage,
    },
  ],
});

export default useUserStore;
